camt.fwer.rejection: Return the rejected hypotheses at a given significance level.

Description Usage Arguments Value Author(s) References Examples

Description

The function outputs the indices of the rejected hypotheses at a specified signficance level.

Usage

1
camt.fwer.rejection(camt.fwer.obj, alpha = 0.1)

Arguments

camt.fwer.obj

the output from running 'camt.fwer'.

alpha

a numeric value for the desired signficance level.

Value

A vector containing the indices of the rejected hypotheses.

Author(s)

Huijuan Zhou

References

Huijuan Zhou, Xianyang Zhang, Jun Chen. Covariate Adaptive Family-wise Error Control with Applications to Genome-wide Association Studies. Submitted.

Examples

1
2
3
4
data <- simulate.data(feature.no = 10000, covariate.strength = 'Moderate', covariate.model = 'pi0',
	sig.density = 'Medium', sig.strength = 'L4', cor.struct = 'None')
camt.obj.fwer <- camt.fwer(pvals = data$pvals, pi0.var = data$pi0.var)
camt.fwer.rejection(camt.obj.fwer, alpha = 0.1)

jchen1981/CAMT documentation built on Jan. 2, 2021, 1:44 p.m.