Description Usage Arguments Value Author(s) References Examples
The function outputs the indices of the rejected hypotheses at a specified signficance level.
1 | camt.fwer.rejection(camt.fwer.obj, alpha = 0.1)
|
camt.fwer.obj |
the output from running |
alpha |
a numeric value for the desired signficance level. |
A vector containing the indices of the rejected hypotheses.
Huijuan Zhou
Huijuan Zhou, Xianyang Zhang, Jun Chen. Covariate Adaptive Family-wise Error Control with Applications to Genome-wide Association Studies. Submitted.
1 2 3 4 | data <- simulate.data(feature.no = 10000, covariate.strength = 'Moderate', covariate.model = 'pi0',
sig.density = 'Medium', sig.strength = 'L4', cor.struct = 'None')
camt.obj.fwer <- camt.fwer(pvals = data$pvals, pi0.var = data$pi0.var)
camt.fwer.rejection(camt.obj.fwer, alpha = 0.1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.